Description Usage Arguments Details Value Author(s) Examples
Scan a file of R code for the presence of functions from packages installed on machine or a custom list of packages.
1 |
|
A connection to a file (.R or .Rmd) containing package functions. |
|
Optionally specify a character vector of packages to be searched for. |
|
Optional character vector of package names to ignore. |
|
Logical stating whether packages should be detached after input. Default is TRUE. |
Add :: notation to functions so that packages are directly referenced in their calls.
R package development requires not attaching packages and instead loading them directly by package::function.
This function and package exists to negate manually appending package identifyers to corresponding functions in R code.
An edited .R file written to the same directory as input file.
Spencer Seale
1 2 3 4 | ## Not run:
addPid("/path/to/r/script")
## End(Not run)
|
Add the following code to your website.
For more information on customizing the embed code, read Embedding Snippets.